@@ -408,28 +408,21 @@ func (i *NomadInstaller) Upgrade(
 	}
 
 	s.Update("Waiting for allocation to be scheduled")
-EVAL:
 	qopts := &api.QueryOptions{
 		WaitIndex: resp.EvalCreateIndex,
+		WaitTime:  time.Duration(500 * time.Millisecond),
 	}
 
-	eval, meta, err := client.Evaluations().Info(resp.EvalID, qopts)
+	eval, meta, err := i.waitForEvaluation(ctx, s, client, resp, qopts)
 	if err != nil {
-		return nil, err
-	}
-	qopts.WaitIndex = meta.LastIndex
-	switch eval.Status {
-	case "pending":
-		goto EVAL
-	case "complete":
-		s.Update("Nomad allocation created")
-	case "failed", "canceled", "blocked":
 		s.Update("Nomad failed to schedule the waypoint server ", serverName)
 		s.Status(terminal.StatusError)
-		return nil, fmt.Errorf("nomad evaluation did not transition to 'complete'")
-	default:
-		return nil, fmt.Errorf("unknown eval status: %q", eval.Status)
+		return nil, err
 	}
+	if eval == nil {
+		return nil, fmt.Errorf("evaluation status could not be determined")
+	}
+	qopts.WaitIndex = meta.LastIndex
 
 	var allocID string
 
@@ -599,6 +592,9 @@ func (i *NomadInstaller) Uninstall(ctx context.Context, opts *InstallOpts) error
 	s.Update("Waypoint job and allocations purged")
 
 	vols, _, err := client.CSIVolumes().List(&api.QueryOptions{Prefix: "waypoint"})
+	if err != nil {
+		return err
+	}
 	for _, vol := range vols {
 		if vol.ID == "waypoint" {
 			s.Update("Destroying persistent CSI volume")
@@ -756,30 +752,23 @@ func (i *NomadInstaller) runJob(
 	}
 
 	s.Update("Waiting for allocation to be scheduled")
-EVAL:
 	qopts := &api.QueryOptions{
 		WaitIndex: resp.EvalCreateIndex,
+		WaitTime:  time.Duration(500 * time.Millisecond),
 	}
 
-	eval, meta, err := client.Evaluations().Info(resp.EvalID, qopts)
+	eval, meta, err := i.waitForEvaluation(ctx, s, client, resp, qopts)
 	if err != nil {
 		return "", err
 	}
-	qopts.WaitIndex = meta.LastIndex
-	switch eval.Status {
-	case "pending":
-		goto EVAL
-	case "complete":
-		s.Update("Nomad allocation created")
-	case "failed", "canceled", "blocked":
-		s.Update("Nomad failed to schedule the job")
-		s.Status(terminal.StatusError)
-		return "", fmt.Errorf("nomad evaluation did not transition to 'complete'")
-	default:
-		return "", fmt.Errorf("unknown eval status: %q", eval.Status)
+	if eval == nil {
+		return "", fmt.Errorf("evaluation status could not be determined")
 	}
+	qopts.WaitIndex = meta.LastIndex
 
 	var allocID string
+	retries := 0
+	maxRetries := 3
 	for {
 		allocs, qmeta, err := client.Evaluations().Allocations(eval.ID, qopts)
 		if err != nil {
@@ -794,6 +783,7 @@ EVAL:
 		case "running":
 			allocID = allocs[0].ID
 			s.Update("Nomad allocation running")
+			retries++
 		case "pending":
 			s.Update(fmt.Sprintf("Waiting for allocation %q to start", allocs[0].ID))
 			// retry
@@ -802,7 +792,12 @@ EVAL:
 		}
 
 		if allocID != "" {
-			return allocID, nil
+			if retries == maxRetries {
+				return allocID, nil
+			} else {
+				s.Update("Ensuring allocation %q has properly started up...", allocs[0].ID)
+				time.Sleep(1 * time.Second)
+			}
 		}
 
 		select {
@@ -813,6 +808,39 @@ EVAL:
 	}
 }
 
+func (i *NomadInstaller) waitForEvaluation(
+	ctx context.Context,
+	s terminal.Step,
+	client *api.Client,
+	resp *api.JobRegisterResponse,
+	qopts *api.QueryOptions,
+) (*api.Evaluation, *api.QueryMeta, error) {
+
+	for {
+		eval, meta, err := client.Evaluations().Info(resp.EvalID, qopts)
+		if err != nil {
+			return nil, nil, err
+		}
+
+		qopts.WaitIndex = meta.LastIndex
+
+		switch eval.Status {
+		case "pending":
+			s.Update("Nomad allocation pending...")
+		case "complete":
+			s.Update("Nomad allocation created")
+
+			return eval, meta, nil
+		case "failed", "canceled", "blocked":
+			s.Update("Nomad failed to schedule the job")
+			s.Status(terminal.StatusError)
+			return nil, nil, fmt.Errorf("Nomad evaluation did not transition to 'complete'")
+		default:
+			return nil, nil, fmt.Errorf("receieved unknown eval status from Nomad: %q", eval.Status)
+		}
+	}
+}
+
 // waypointNomadJob takes in a nomadConfig and returns a Nomad Job per the
 // Nomad API
 func waypointNomadJob(c nomadConfig, rawRunFlags []string) *api.Job {
@@ -1076,11 +1104,12 @@ func (i *NomadInstaller) OnDemandRunnerConfig() *pb.OnDemandRunnerConfig {
 	}
 
 	return &pb.OnDemandRunnerConfig{
+		Name:         "nomad",
 		OciUrl:       i.config.odrImage,
 		PluginType:   "nomad",
 		Default:      true,
 		PluginConfig: cfgJson,
-		ConfigFormat: pb.Project_JSON,
+		ConfigFormat: pb.Hcl_JSON,
 	}
 }
 
